import React from 'react'
import ReactDOM from 'react-dom/client'
import { BrowserRouter } from 'react-router-dom'
import App from './App.jsx'
import ScrollToTop from './components/ScrollToTop'
import './index.css'
import './i18n.js'

// Detailed error logging
console.log('main.jsx loaded');
console.log('React version:', React.version);
console.log('ReactDOM version:', ReactDOM.version);

// Try-catch block to catch any initialization errors
try {
  // Get the root element
  const rootElement = document.getElementById('root');

  // Log for debugging
  console.log('Initializing React app, root element:', rootElement);

  if (rootElement) {
    // Create a simple error boundary
    class ErrorBoundary extends React.Component {
      constructor(props) {
        super(props);
        this.state = { hasError: false, error: null, errorInfo: null };
      }

      static getDerivedStateFromError(error) {
        return { hasError: true };
      }

      componentDidCatch(error, errorInfo) {
        console.error('React Error Boundary caught an error:', error, errorInfo);
        this.setState({ error, errorInfo });
      }

      render() {
        if (this.state.hasError) {
          return (
            <div style={{ padding: '20px', fontFamily: 'Arial, sans-serif' }}>
              <h1 style={{ color: 'red' }}>Something went wrong</h1>
              <p>The application encountered an error during initialization.</p>
              <details style={{ whiteSpace: 'pre-wrap', marginTop: '20px' }}>
                <summary>Error Details</summary>
                {this.state.error && this.state.error.toString()}
                <br />
                {this.state.errorInfo && this.state.errorInfo.componentStack}
              </details>
            </div>
          );
        }
        return this.props.children;
      }
    }

    // Render with error boundary
    ReactDOM.createRoot(rootElement).render(
      <React.StrictMode>
        <ErrorBoundary>
          <BrowserRouter future={{ v7_startTransition: true, v7_relativeSplatPath: true }}>
            <ScrollToTop />
            <App />
          </BrowserRouter>
        </ErrorBoundary>
      </React.StrictMode>
    );

    console.log('React app rendered successfully');
  } else {
    console.error('Root element not found!');
    // Try to create a message in the body if root element is not found
    document.body.innerHTML = `
      <div style="padding: 20px; font-family: Arial, sans-serif;">
        <h1 style="color: red;">Error: Root Element Not Found</h1>
        <p>The application could not find the root element with id="root".</p>
        <p>Please check your HTML structure and make sure the root element exists.</p>
      </div>
    `;
  }
} catch (error) {
  console.error('Error initializing React application:', error);
  // Display error on page
  document.body.innerHTML = `
    <div style="padding: 20px; font-family: Arial, sans-serif;">
      <h1 style="color: red;">React Initialization Error</h1>
      <p>The application encountered an error during initialization:</p>
      <pre style="background-color: #f8f8f8; padding: 10px; border-radius: 4px; overflow: auto;">
        ${error.message}
        ${error.stack}
      </pre>
    </div>
  `;
}
